handlers

package
v0.0.0-...-7fd5371 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 1, 2021 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func EditForm

func EditForm(w http.ResponseWriter, r *http.Request)

EditForm - save input to file

func EditView

func EditView(w http.ResponseWriter, r *http.Request)

EditView - view rendered markdown

func MarkdownView

func MarkdownView(w http.ResponseWriter, r *http.Request)

MarkdownView - view rendered markdown

Types

type EditTemplateData

type EditTemplateData struct {
	WikiTitle string
	Markdown  string
}

EditTemplateData is the data we pass to the edit html template

type ViewTemplateData

type ViewTemplateData struct {
	WikiTitle    string
	MarkdownHTML template.HTML
}

ViewTemplateData is the data we pass to the view html template

Jump to