Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EditView ¶
func EditView(w http.ResponseWriter, r *http.Request)
EditView - view rendered markdown
func MarkdownView ¶
func MarkdownView(w http.ResponseWriter, r *http.Request)
MarkdownView - view rendered markdown
Types ¶
type EditTemplateData ¶
EditTemplateData is the data we pass to the edit html template
type ViewTemplateData ¶
ViewTemplateData is the data we pass to the view html template
Click to show internal directories.
Click to hide internal directories.